Apply a pre-built or custom coded theme to a chart
Arguments
- wt
Required
echartywidget as returned by ec.init- name
Name of existing theme file (without extension), or name of custom theme defined in
code.- code
Custom theme as JSON formatted string, default NULL.
Details
Just a few built-in themes are included in folder inst/themes.
Their names are dark, gray, jazz, dark-mushroom and macarons.
The entire ECharts theme collection could be found here and files copied if needed.
To create custom themes or view predefined ones, visit theme-builder.
See also alternative registerTheme in ec.init.